/*
 * file Configuration.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 * 
 * (c) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */
package javax.wvcm;

import javax.wvcm.PropertyNameList.PropertyName;

/**
 * A proxy for a configuration resource.
 *
 * A configuration resource is a controlled resource that is associated with a folder
 * (called the "root folder") and that represents all controlled members
 * of the root folder.
 * <p>
 * A configuration is associated with a
 * baseline-controlled folder, and is used to create and access
 * baselines of that folder.
 * <p>
 * When a folder is both version-controlled and baseline-controlled,
 * a client can create a new version of the folder by
 * checking out and checking in that folder,
 * and it can create a new baseline of that folder by checking out
 * and checking in the configuration of that folder.
 * 
 * @since 1.0
 */
public interface Configuration extends ControllableResource {

    /**
     * The root folder for this configuration. 
     * The {@link ControllableFolder#ROOT_FOLDER_OF} property of the root folder of
     * a configuration MUST identify that configuration.
     * The root {@link ControllableResource#CONFIGURATION} property of a member
     * of the root folder of a configuration must all identify that configuration.
     */
    public static final PropertyName<ControllableFolder> ROOT_FOLDER =
        new PropertyName<ControllableFolder>("root-folder"); //$NON-NLS-1$

    /**
     * Get the {@link #ROOT_FOLDER} property.
     * 
     * @return the {@link #ROOT_FOLDER} property.
     * @throws WvcmException if this Configuration was not created with
     * {@link #ROOT_FOLDER} as a wanted property.
     */
    public ControllableFolder getRootFolder() throws WvcmException;

}
